
local addon, ns = ...
local media = "Interface\\AddOns\\"..addon.."\\media\\"
local textures = {
	{media.."warn_a",media.."warn_b"},
	{"Interface\\FullScreenTextures\\LowHealth","Interface\\FullScreenTextures\\OutOfControl"},
	{media.."warn_c",media.."warn_c"}
}
local currentTex = 3
local fadingType = 3

local f = CreateFrame("frame","AFK_fullscreen_Frame",UIParent)

f.alpha, f.fade = {min=0,max=0.7,step=0.02}, {["in"]=0.04,["in_hold"]=0.01,["out"]=0.04,["out_hold"]=0.01}
f.mode, f.duration, f.timer, f.odd, f.isAFK = "in", 0, 0, true, false

f:SetFrameStrata("FULLSCREEN_DIALOG")
f:SetToplevel(true)
f:SetAllPoints()
f:Hide()

f.tx1 = f:CreateTexture(nil,"BACKGROUND")
f.tx1:SetTexture(textures[currentTex][1])
f.tx1:SetBlendMode("ADD")
f.tx1:SetAllPoints()

f.tx2 = f:CreateTexture(nil,"BACKGROUND")
f.tx2:SetTexture(textures[currentTex][2])
f.tx2:SetBlendMode("ADD")
f.tx2:SetAllPoints()
f.tx2:SetAlpha(0)

f.txt = f:CreateFontString(nil,"BACKGROUND","GameFontNormal")
local ff,_,fs = f.txt:GetFont()
f.txt:SetFont(ff,50,fs)
f.txt:SetTextHeight(60)
f.txt:SetPoint("CENTER",f,"CENTER",0,0)
f.txt:SetAlpha(0.8)

f.switchTexture = function()
	if f.odd then
		f.tx1:Show() f.tx2:Hide()
	else
		f.tx1:Hide() f.tx2:Show()
	end
	f.odd = (not f.odd)
end

f.fading = {
	{
		["in"]       = function(self)
			self.tx1:SetAlpha(self.tx1:GetAlpha()+self.alpha.step)
			self.tx2:SetAlpha(self.tx2:GetAlpha()-self.alpha.step)
			if self.tx1:GetAlpha()>=self.alpha.max then
				self.mode = "in_hold"
			end
		end,
		["out"]      = function(self)
			self.tx1:SetAlpha(self.tx1:GetAlpha()-self.alpha.step)
			self.tx2:SetAlpha(self.tx2:GetAlpha()+self.alpha.step)
			if self.tx1:GetAlpha()<=self.alpha.min then
				self.mode = "out_hold"
			end
		end,
		["in_hold"]  = function(self)
			self.mode = "out"
		end,
		["out_hold"] = function(self)
			self.mode = "in"
		end
	},
	{
		["in"]       = function(self)
			self.tx1:SetAlpha(self.tx1:GetAlpha()-self.alpha.step)
			if self.tx1:GetAlpha()<=self.alpha.min then
				self.mode = "in_hold"
				self.tx1:SetAlpha(self.alpha.min)
				self.tx2:SetAlpha(self.alpha.max)
			end
		end,
		["out"]      = function(self)
			self.tx2:SetAlpha(self.tx2:GetAlpha()-self.alpha.step)
			if self.tx2:GetAlpha()<=self.alpha.min then
				self.mode = "out_hold"
				self.tx1:SetAlpha(self.alpha.max)
				self.tx2:SetAlpha(self.alpha.min)
			end
		end,
		["in_hold"]  = function(self)
			self.mode = "out"
		end,
		["out_hold"] = function(self)
			self.mode = "in"
		end
	},
	{
		["in"]       = function(self)
			local x = self.odd and self.tx1 or self.tx2
			x:SetAlpha(x:GetAlpha()+self.alpha.step)
			if x:GetAlpha()>=self.alpha.max then
				self.mode = "in_hold"
			end
		end,
		["out"]      = function(self)
			local x = self.odd and self.tx1 or self.tx2
			x:SetAlpha(x:GetAlpha()-self.alpha.step)
			if x:GetAlpha()<=self.alpha.min then
				self.mode = "out_hold"
				self.odd = (not self.odd)
			end
		end,
		["in_hold"]  = function(self)
			self.mode = "out"
		end,
		["out_hold"] = function(self)
			self.mode = "in"
		end
	}
}

f.update = function(self,elapsed)
	self.duration = self.duration + elapsed
	if self.fade[self.mode]<=self.duration then
		self.duration=0
		self.fading[fadingType][self.mode](self)
		f.txt:SetText("AFK since:|n"..(SecondsToTime(GetTime()-f.timer)))
	end
end

f:SetScript("OnEvent", function(self,event,arg1)
	if event == "PLAYER_ENTERING_WORLD" then
		self:RegisterEvent("PLAYER_FLAGS_CHANGED")
	elseif event == "PLAYER_FLAGS_CHANGED" and arg1=="player" then
		if UnitIsAFK(arg1) == 1 then
			self.mode="in_hold"
			self.odd=true
			self.duration=0
			self.timer=GetTime()
			self:SetScript("OnUpdate", self.update)
			self:Show()
		else
			self:SetScript("OnUpdate", nil)
			self:Hide()
		end
	end
end)

f:RegisterEvent("PLAYER_ENTERING_WORLD")
